package com.huimv.eartag2.manage.controller;

import com.huimv.eartag2.common.utils.Result;
import com.huimv.eartag2.manage.service.ICacheService;
import com.huimv.eartag2.manage.service.IDeviceService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.text.ParseException;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@RestController
@RequestMapping(value = "/device")
@Slf4j
public class DeviceController {
    @Autowired
    private ICacheService cacheService;
    @Autowired
    private RabbitTemplate rabbitTemplate;
    @Autowired
    private IDeviceService deviceService;

    /**
     * @Method      : getNowAllStatus
     * @Description : 读取最新设备和耳标总状态
     * @Params      : []
     * @Return      : void
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/3/5       
     * @Time        : 17:03
     */
    @RequestMapping(value = "/getNowAllStatus",method = RequestMethod.GET)
    public Result getNowAllStatus(@RequestParam(value = "farmId",required = true) String farmId) throws ParseException {
        log.info("<getNowAllStatus>输入参数 farmId>>"+farmId);
        //
        return deviceService.getNowAllStatus(farmId);
    }

    /**
     * @Method      : listManyDaysAllStatus
     * @Description : 显示N天的总状态记录
     * @Params      : [farmId, days]
     * @Return      : com.huimv.eartag2.common.utils.Result
     *
     * @Author      : ZhuoNing
     * @Date        : 2022/3/6
     * @Time        : 22:18
     */
    @RequestMapping(value = "/listManyDaysAllStatus",method = RequestMethod.GET)
    public Result listManyDaysAllStatus(@RequestParam(value = "farmId",required = true) String farmId,@RequestParam(value = "days",required = true) Integer days) throws ParseException {
        log.info("<listManyDaysAllStatus>输入参数 farmId>>"+farmId);
        log.info("<listManyDaysAllStatus>输入参数 days>>"+days);
        if(days == null){
            //默认7天数据
            days = 7;
        }
        //
        return deviceService.listManyDaysAllStatus(farmId,days);
    }

    /**
     * @Method      : listOnlineDevice
     * @Description : 显示当天在线设备记录
     * @Params      : [farmId]
     * @Return      : com.huimv.eartag2.common.utils.Result
     *
     * @Author      : ZhuoNing
     * @Date        : 2022/3/7
     * @Time        : 11:09
     */
    @RequestMapping(value = "/listOnlineDevice",method = RequestMethod.GET)
    public Result listOnlineDevice(@RequestParam(value = "farmId",required = true) String farmId) throws ParseException {
        log.info("<listOnlineDevice>输入参数 farmId>>"+farmId);
        //
        return deviceService.listOnlineDevice(farmId);
    }

    /**
     * @Method      : getDeviceRegisterByDeviceCode
     * @Description : 通过设备编码查询设备注册信息
     * @Params      : [deviceCode]
     * @Return      : com.huimv.eartag2.common.utils.Result
     * 
     * @Author      : ZhuoNing
     * @Date        : 2022/3/7       
     * @Time        : 14:01
     */
    @RequestMapping(value = "/getDeviceRegisterByDeviceCode",method = RequestMethod.GET)
    public Result getDeviceRegisterByDeviceCode(@RequestParam(value = "deviceCode",required = true) String deviceCode){
        log.info("<getDeviceRegisterByDeviceCode>输入参数 deviceCode>>"+deviceCode);
        //
        return deviceService.getDeviceRegisterByDeviceCode(deviceCode);
    }

}
